#!/usr/bin/env python
import os
import subprocess
import stat

xplane_installs = set()
with open(os.path.expanduser("~") + "/Library/Preferences/x-plane_install_11.txt") as loc_file:
    for line in loc_file:
        if line.startswith("/"):
            xplane_installs.add(line.strip())

current_path = os.path.realpath(__file__)
XPLANE_DIR_NAME = "X-Plane 11"
if XPLANE_DIR_NAME in current_path:
    while not current_path.endswith(XPLANE_DIR_NAME):
        current_path = os.path.abspath(os.path.join(current_path, '..'))
    xplane_installs.add(current_path)

with open(os.path.expanduser("~") + "/Desktop/file_permissions_log.txt", "w") as ouf:
    for install in xplane_installs:
        ouf.write("Beginning permissions fix for X-Plane install " + install + "\n")
        for current_directory, subdirs, files in os.walk(install):
            # Don't recurse on hidden directories (replacing elements of subdirs alters the recursion... weirdly)
            subdirs[:] = [d for d in subdirs if not d[0] == '.']

            for item in files + subdirs:
                path_to_file_or_folder = current_directory + os.sep + item
                if os.path.exists(path_to_file_or_folder):
                    st = os.stat(path_to_file_or_folder)
                    is_writable_by_user = bool(st.st_mode & stat.S_IWUSR)
                    if not is_writable_by_user:
                        ouf.write("Fixing permissions on " + path_to_file_or_folder + "\n")
                        subprocess.check_call("sudo chmod 777 " + path_to_file_or_folder.replace(" ", "\ "), shell=True)
                        # os.chmod(path_to_file_or_folder, 0o777)
                        st = os.stat(path_to_file_or_folder)
                        fix_worked = bool(st.st_mode & stat.S_IWUSR)
                        if not fix_worked:
                            ouf.write("\tFailed!\n")
        ouf.write("\n")



